@@ -276,7 +276,11 @@ class Thread:
                     skip_git_repo_check=self._thread_options.skip_git_repo_check,
                     output_schema_file=schema_path,
                     model_reasoning_effort=self._thread_options.model_reasoning_effort,
+                    model_instructions_file=self._thread_options.model_instructions_file,
+                    model_personality=self._thread_options.model_personality,
+                    max_threads=self._thread_options.max_threads,
                     network_access_enabled=self._thread_options.network_access_enabled,
+                    web_search_mode=self._thread_options.web_search_mode,
                     web_search_enabled=self._thread_options.web_search_enabled,
                     web_search_cached_enabled=self._thread_options.web_search_cached_enabled,
                     skills_enabled=self._thread_options.skills_enabled,
@@ -285,6 +289,8 @@ class Thread:
                     apply_patch_freeform_enabled=self._thread_options.apply_patch_freeform_enabled,
                     exec_policy_enabled=self._thread_options.exec_policy_enabled,
                     remote_models_enabled=self._thread_options.remote_models_enabled,
+                    collaboration_modes_enabled=self._thread_options.collaboration_modes_enabled,
+                    responses_websockets_enabled=self._thread_options.responses_websockets_enabled,
                     request_compression_enabled=self._thread_options.request_compression_enabled,
                     feature_overrides=self._thread_options.feature_overrides,
                     approval_policy=self._thread_options.approval_policy,
